starcluster.balancers

Package starcluster :: Package balancers |
[hide private]
[frames] | no frames]

# Source Code for Package starcluster.balancers

     1  #!/usr/bin/env python
     2
     3
     4 -class LoadBalancer(object):
     5      """
     6      Base class for all load balancers
     7      """
     8 -    def __init__(self):
     9          pass
    10
    11 -    def run(self, cluster):
    12          pass
    13